==> aioaws-0.2.tar.gz: aioaws-0.2/setup.py <==
import os
import re
import sys
from importlib.machinery import SourceFileLoader
from pathlib import Path

from setuptools import setup


description = 'Data validation and settings management using python 3.6 type hinting'
THIS_DIR = Path(__file__).resolve().parent
try:
    long_description = (THIS_DIR / 'README.md').read_text()
except FileNotFoundError:
    long_description = description + '.\n\nSee TODO for documentation.'

# avoid loading the package before requirements are installed:
version = SourceFileLoader('version', 'aioaws/version.py').load_module()

ext_modules = None

setup(
    name='aioaws',
    version=str(version.VERSION),
    description=description,
    long_description=long_description,
    long_description_content_type='text/markdown',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.8',
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: MIT License',
        'Operating System :: Unix',
        'Operating System :: POSIX :: Linux',
        'Environment :: Console',
        'Environment :: MacOS X',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Internet',
    ],
    author='Samuel Colvin',
    author_email='s@muelcolvin.com',
    url='https://github.com/samuelcolvin/aioaws',
    license='MIT',
    packages=['aioaws'],
    package_data={'aioaws': ['py.typed']},
    python_requires='>=3.8',
    zip_safe=False,  # https://mypy.readthedocs.io/en/latest/installed_packages.html
    install_requires=[
        'pydantic>=1.4',
        'httpx>=0.12.1',
    ],
)

==> aioaws-0.3.tar.gz: aioaws-0.3/setup.py <==
from importlib.machinery import SourceFileLoader
from pathlib import Path

from setuptools import setup


description = 'Data validation and settings management using python 3.6 type hinting'
THIS_DIR = Path(__file__).resolve().parent
try:
    long_description = (THIS_DIR / 'README.md').read_text()
except FileNotFoundError:
    long_description = description + '.\n\nSee TODO for documentation.'

# avoid loading the package before requirements are installed:
version = SourceFileLoader('version', 'aioaws/version.py').load_module()

ext_modules = None

setup(
    name='aioaws',
    version=version.VERSION,
    description=description,
    long_description=long_description,
    long_description_content_type='text/markdown',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.8',
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: MIT License',
        'Operating System :: Unix',
        'Operating System :: POSIX :: Linux',
        'Environment :: Console',
        'Environment :: MacOS X',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Internet',
    ],
    author='Samuel Colvin',
    author_email='s@muelcolvin.com',
    url='https://github.com/samuelcolvin/aioaws',
    license='MIT',
    packages=['aioaws'],
    package_data={'aioaws': ['py.typed']},
    python_requires='>=3.8',
    zip_safe=False,  # https://mypy.readthedocs.io/en/latest/installed_packages.html
    install_requires=[
        'aiofiles>=0.5.0',
        'httpx>=0.15.5',
        'pydantic>=1.6.1',
    ],
)
